Changelog
=========

2.1 (2021-05-12)
----------------

- Add dict API methods on `BeakerSessionDataObject` for plone addons compatibility
  [mpeeters]


2.0 (2021-05-12)
----------------

- Python 3 compatibility and drop Python 2.6 compability
  [mpeeters]


1.1 (2011-12-05)
----------------

- Made compatible with Zope 2.10.
  [davisagli]

1.0 (2011-06-29)
----------------

- Add test and fix for missing __len__.
  [kuetrzi]

1.0b1 (2011-04-17)
------------------

- Initial release.
  [davisagli]
